import { inArray } from 'drizzle-orm';
import { buildVersionCollectionFields } from 'payload';
import toSnakeCase from 'to-snake-case';
import { findMany } from './find/findMany.js';
import { getTransaction } from './utilities/getTransaction.js';
export const deleteVersions = async function deleteVersion({ collection, locale, req, where: where }) {
    const db = await getTransaction(this, req);
    const collectionConfig = this.payload.collections[collection].config;
    const tableName = this.tableNameMap.get(`_${toSnakeCase(collectionConfig.slug)}${this.versionsSuffix}`);
    const fields = buildVersionCollectionFields(this.payload.config, collectionConfig, true);
    const { docs } = await findMany({
        adapter: this,
        fields,
        joins: false,
        limit: 0,
        locale,
        page: 1,
        pagination: false,
        req,
        tableName,
        where
    });
    const ids = [];
    docs.forEach((doc)=>{
        ids.push(doc.id);
    });
    if (ids.length > 0) {
        await this.deleteWhere({
            db,
            tableName,
            where: inArray(this.tables[tableName].id, ids)
        });
    }
    return docs;
};

//# sourceMappingURL=deleteVersions.js.map